antares.apps.client.service package
===================================

Module contents
---------------

.. automodule:: antares.apps.client.service
   :members:
   :undoc-members:
   :show-inheritance:
